@@ -117,9 +117,13 @@ get_sources(){
         echo "Sources will not be downloaded"
         return 0
     fi
+    IS_RELEASE_BRANCH=$(echo ${VERSION} | grep -c release)
+    if [ ${IS_RELEASE_BRANCH} != 0 ]; then
+        VERSION=$(echo $VERSION | awk -F'-' '{print $2}')
+    fi
     PRODUCT=percona-pg-stat-monitor${PG_RELEASE}
     PRODUCT_FULL=${PRODUCT}-${VERSION}
-
+    
     echo "PRODUCT=${PRODUCT}" > pg-stat-monitor.properties
     echo "PRODUCT_FULL=${PRODUCT_FULL}" >> pg-stat-monitor.properties
     echo "VERSION=${VERSION}" >> pg-stat-monitor.properties
@@ -162,7 +166,8 @@ get_sources(){
     source pg-stat-monitor.properties
     #
     tar --owner=0 --group=0 --exclude=.* -czf ${PRODUCT_FULL}.tar.gz ${PRODUCT_FULL}
-    echo "UPLOAD=UPLOAD/experimental/BUILDS/${PRODUCT}/${PRODUCT_FULL}/${BRANCH}/${REVISION}/${BUILD_ID}" >> pg-stat-monitor.properties
+    DATE_TIMESTAMP=$(date +%F_%H-%M-%S)
+    echo "UPLOAD=UPLOAD/experimental/BUILDS/${PRODUCT}/${PRODUCT_FULL}/${BRANCH}/${REVISION}/${DATE_TIMESTAMP}/${BUILD_ID}" >> pg-stat-monitor.properties
     mkdir $WORKDIR/source_tarball
     mkdir $CURDIR/source_tarball
     cp ${PRODUCT_FULL}.tar.gz $WORKDIR/source_tarball
@@ -204,9 +209,6 @@ install_deps() {
     then
         yum -y install git wget
         yum install -y https://repo.percona.com/yum/percona-release-latest.noarch.rpm
-        wget https://raw.githubusercontent.com/percona/percona-repositories/release-1.0-28/scripts/percona-release.sh
-        mv percona-release.sh /usr/bin/percona-release
-        chmod 777 /usr/bin/percona-release
         percona-release enable ${PPG_REPO_NAME} testing
 
         if [ x"$RHEL" = x8 ];
@@ -263,13 +265,15 @@ install_deps() {
         apt-get update
 
         if [[ "${OS_NAME}" != "focal" ]]; then
-            LLVM_EXISTS=$(grep -c "apt.llvm.org" /etc/apt/sources.list)
-            if [ "${LLVM_EXISTS}" == 0 ]; then
-                wget -O - https://apt.llvm.org/llvm-snapshot.gpg.key|sudo apt-key add -
-                echo "deb http://apt.llvm.org/${OS_NAME}/ llvm-toolchain-${OS_NAME}-7 main" >> /etc/apt/sources.list
-                echo "deb-src http://apt.llvm.org/${OS_NAME}/ llvm-toolchain-${OS_NAME}-7 main" >> /etc/apt/sources.list
-                apt-get update
-            fi
+            #LLVM_EXISTS=$(grep -c "apt.llvm.org" /etc/apt/sources.list)
+            #if [ "${LLVM_EXISTS}" == 0 ]; then
+                #wget -O - https://apt.llvm.org/llvm-snapshot.gpg.key|sudo apt-key add -
+                #echo "deb http://apt.llvm.org/${OS_NAME}/ llvm-toolchain-${OS_NAME}-7 main" >> /etc/apt/sources.list
+                #echo "deb-src http://apt.llvm.org/${OS_NAME}/ llvm-toolchain-${OS_NAME}-7 main" >> /etc/apt/sources.list
+                #apt-get update
+            #fi
+			wget http://mirrors.kernel.org/ubuntu/pool/universe/l/llvm-toolchain-7/llvm-7_7.0.1-12_amd64.deb http://mirrors.kernel.org/ubuntu/pool/universe/l/llvm-toolchain-7/libllvm7_7.0.1-12_amd64.deb http://mirrors.kernel.org/ubuntu/pool/universe/l/llvm-toolchain-7/llvm-7-runtime_7.0.1-12_amd64.deb
+            apt install ./libllvm7_7.0.1-12_amd64.deb ./llvm-7_7.0.1-12_amd64.deb ./llvm-7-runtime_7.0.1-12_amd64.deb
         fi
 
         PKGLIST+=" debconf debhelper clang devscripts dh-exec git wget libkrb5-dev libssl-dev"
@@ -400,6 +404,9 @@ build_rpm(){
     fi
     export LIBPQ_DIR=/usr/pgsql-${PG_RELEASE}/
     export LIBRARY_PATH=/usr/pgsql-${PG_RELEASE}/lib/:/usr/pgsql-${PG_RELEASE}/include/
+    if [[ "${RHEL}" -eq 10 ]]; then
+        export QA_RPATHS=0x0002
+    fi
     rpmbuild --define "_topdir ${WORKDIR}/rpmbuild" --define "dist .$OS_NAME" --define "version ${VERSION}" --rebuild rpmbuild/SRPMS/$SRC_RPM
 
     return_code=$?
