@@ -1,4 +1,4 @@
-Drop Table if exists Company;
+DROP TABLE IF EXISTS Company;
 
 CREATE TABLE Company(
    ID INT PRIMARY KEY     NOT NULL,
@@ -11,7 +11,7 @@ SELECT pg_stat_monitor_reset();
 INSERT  INTO Company(ID, Name) VALUES (1, 'Percona'); 
 INSERT  INTO Company(ID, Name) VALUES (1, 'Percona'); 
 
-Drop Table if exists Company;
+DROP TABLE IF EXISTS Company;
 SELECT query, elevel, sqlcode, message FROM pg_stat_monitor ORDER BY query COLLATE "C",elevel;
 SELECT pg_stat_monitor_reset();
 DROP EXTENSION pg_stat_monitor;
